@@ -2,7 +2,6 @@ from bs4 import BeautifulSoup
 from django import forms
 from django.forms import formset_factory
 
-from django_bootstrap5.exceptions import BootstrapError
 from tests.base import BootstrapTestCase
 
 
@@ -25,14 +24,24 @@ class NonFieldErrorTestForm(FormTestForm):
 
 class BootstrapFormTestCase(BootstrapTestCase):
     def test_illegal_form(self):
-        with self.assertRaises(BootstrapError):
+        with self.assertRaises(TypeError):
             self.render("{% bootstrap_form form %}", {"form": "illegal"})
 
     def test_exclude(self):
         html = self.render('{% bootstrap_form form exclude="optional_text" %}', {"form": FormTestForm()})
-        self.assertNotIn("optional_text", html)
+        self.assertHTMLEqual(
+            html,
+            (
+                '<div class="mb-3 django_bootstrap5-req">'
+                '<label class="form-label" for="id_required_text">Required text</label>'
+                '<input type="text" name="required_text" class="form-control"'
+                ' placeholder="Required text" required id="id_required_text">'
+                '<div class="form-text"><i>required_text_help</i>'
+                "</div>"
+            ),
+        )
 
-    def test_error_class(self):
+    def test_error_css_class(self):
         form = FormTestForm({"optional_text": "my_message"})
 
         html = self.render("{% bootstrap_form form %}", {"form": form})
@@ -44,7 +53,7 @@ class BootstrapFormTestCase(BootstrapTestCase):
         html = self.render('{% bootstrap_form form error_css_class="" %}', {"form": form})
         self.assertNotIn("django_bootstrap5-err", html)
 
-    def test_required_class(self):
+    def test_required_css_class(self):
         form = FormTestForm({"subject": "subject"})
         html = self.render("{% bootstrap_form form %}", {"form": form})
         self.assertIn("django_bootstrap5-req", html)
@@ -55,21 +64,21 @@ class BootstrapFormTestCase(BootstrapTestCase):
         html = self.render('{% bootstrap_form form required_css_class="" %}', {"form": form})
         self.assertNotIn("django_bootstrap5-req", html)
 
-    def test_bound_class(self):
+    def test_success_css_class(self):
         form = FormTestForm({"subject": "subject"})
 
         html = self.render("{% bootstrap_form form %}", {"form": form})
-        self.assertIn("django_bootstrap5-bound", html)
+        self.assertIn("django_bootstrap5-success", html)
 
         form = FormTestForm({"subject": "subject"})
 
-        html = self.render('{% bootstrap_form form bound_css_class="successful-test" %}', {"form": form})
+        html = self.render('{% bootstrap_form form success_css_class="successful-test" %}', {"form": form})
         self.assertIn("successful-test", html)
 
         form = FormTestForm({"subject": "subject"})
 
-        html = self.render('{% bootstrap_form form bound_css_class="" %}', {"form": form})
-        self.assertNotIn("django_bootstrap5-bound", html)
+        html = self.render('{% bootstrap_form form success_css_class="" %}', {"form": form})
+        self.assertNotIn("django_bootstrap5-success", html)
 
     def test_alert_error_type(self):
         form = NonFieldErrorTestForm({"subject": "subject"})
